@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.2.0';
+our $VERSION = '1.2.6.0';
 
 use Exporter 'import';
 
@@ -38,6 +38,11 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
+# We need to use the RTLD_GLOBAL flag to dlopen() so that other C++
+# modules that link against libxapian.so get the *same* value for all the
+# weak symbols (eg, the exception classes)
+sub dl_load_flags { 0x01 }
+
 # This allows declaration	use Search::Xapian ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
@@ -259,7 +264,7 @@ flags to the default ones.
 
 =item FLAG_BOOLEAN
 
-Support AND, OR, etc and bracketted subexpressions.
+Support AND, OR, etc and bracketed subexpressions.
 
 =item FLAG_LOVEHATE
 
@@ -432,7 +437,8 @@ docs.
 =item Unwrapped classes
 
 The following Xapian classes are not yet wrapped:
-Error (and subclasses), ErrorHandler, ExpandDecider (and subclasses),
+Error (and subclasses), ErrorHandler, standard ExpandDecider subclasses
+(user-defined ones works),
 user-defined weight classes.
 
 We don't yet wrap Xapian::Query::MatchAll, Xapian::Query::MatchNothing,
